@@ -1,12 +1,22 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2017 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the examples of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:BSD$
-** You may use this file under the terms of the BSD license as follows:
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
+**
+** BSD License Usage
+** Alternatively, you may use this file under the terms of the BSD license
+** as follows:
 **
 ** "Redistribution and use in source and binary forms, with or without
 ** modification, are permitted provided that the following conditions are
@@ -103,6 +113,23 @@ Engine::Engine(QObject *parent)
                     this,
                     SLOT(spectrumChanged(FrequencySpectrum)));
 
+    // This code might misinterpret things like "-something -category".  But
+    // it's unlikely that that needs to be supported so we'll let it go.
+    QStringList arguments = QCoreApplication::instance()->arguments();
+    for (int i = 0; i < arguments.count(); ++i) {
+        if (arguments.at(i) == QStringLiteral("--"))
+            break;
+
+        if (arguments.at(i) == QStringLiteral("-category")
+                || arguments.at(i) == QStringLiteral("--category")) {
+            ++i;
+            if (i < arguments.count())
+                m_audioOutputCategory = arguments.at(i);
+            else
+                --i;
+        }
+    }
+
     initialize();
 
 #ifdef DUMP_DATA
@@ -494,6 +521,7 @@ bool Engine::initialize()
             }
             m_audioOutput = new QAudioOutput(m_audioOutputDevice, m_format, this);
             m_audioOutput->setNotifyInterval(NotifyIntervalMs);
+            m_audioOutput->setCategory(m_audioOutputCategory);
         }
     } else {
         if (m_file)
@@ -508,6 +536,7 @@ bool Engine::initialize()
     ENGINE_DEBUG << "Engine::initialize" << "m_bufferLength" << m_bufferLength;
     ENGINE_DEBUG << "Engine::initialize" << "m_dataLength" << m_dataLength;
     ENGINE_DEBUG << "Engine::initialize" << "format" << m_format;
+    ENGINE_DEBUG << "Engine::initialize" << "m_audioOutputCategory" << m_audioOutputCategory;
 
     return result;
 }
