@@ -6,7 +6,17 @@
 ** This file is part of the examples of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:BSD$
-** You may use this file under the terms of the BSD license as follows:
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
+**
+** BSD License Usage
+** Alternatively, you may use this file under the terms of the BSD license
+** as follows:
 **
 ** "Redistribution and use in source and binary forms, with or without
 ** modification, are permitted provided that the following conditions are
@@ -68,8 +78,10 @@ static bool associateFileTypes()
 
     settings.beginGroup(QStringLiteral("SupportedTypes"));
     QMimeDatabase mimeDatabase;
-    foreach (const QString &fileType, MusicPlayer::supportedMimeTypes()) {
-        foreach (QString suffix, mimeDatabase.mimeTypeForName(fileType).suffixes()) {
+    const QStringList supportedMimeTypes = MusicPlayer::supportedMimeTypes();
+    for (const QString &fileType : supportedMimeTypes) {
+        const QStringList suffixes = mimeDatabase.mimeTypeForName(fileType).suffixes();
+        for (QString suffix : suffixes) {
             suffix.prepend('.');
             settings.setValue(suffix, QString());
         }
